@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2017 by Dominique Dumont.
+# This software is Copyright (c) 2015-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -128,9 +128,7 @@ parsed. This is useful to alter or add configuration settings for a unit, withou
 modify unit files. Each drop-in file must have appropriate section headers. Note that for
 instantiated units, this logic will first look for the instance C<.d/>
 subdirectory and read its C<.conf> files, followed by the template
-C<.d/> subdirectory and the C<.conf> files there. Also note that
-settings from the C<[Install]> section are not honored in drop-in unit files,
-and have no effect.
+C<.d/> subdirectory and the C<.conf> files there.
 
 In addition to /etc/systemd/system, the drop-in C<.d>
 directories for system services can be placed in /usr/lib/systemd/system or
@@ -146,23 +144,6 @@ sparingly and instead rely on techniques such as bus-based or
 socket-based activation which make dependencies implicit,
 resulting in a both simpler and more flexible system.
 
-Some unit names reflect paths existing in the file system
-namespace. Example: a device unit
-dev-sda.device refers to a device with the
-device node /dev/sda in the
-file system namespace. If this applies, a special way to escape
-the path name is used, so that the result is usable as part of a
-filename. Basically, given a path, \"/\" is replaced by \"-\", and all
-other characters which are not ASCII alphanumerics are replaced by
-C-style \"\\x2d\" escapes (except that \"_\" is never replaced and \".\"
-is only replaced when it would be the first character in the
-escaped path). The root directory \"/\" is encoded as single dash,
-while otherwise the initial and ending \"/\" are removed from all
-paths during transformation. This escaping is reversible. Properly
-escaped paths can be generated using the
-L<systemd-escape(1)>
-command.
-
 Optionally, units may be instantiated from a
 template file at runtime. This allows creation of
 multiple units from a single configuration file. If
@@ -195,12 +176,25 @@ The unit file format is covered by the
 Interface
 Stability Promise.
 
-Additional units might be loaded into systemd (\"linked\")
-from directories not on the unit load path. See the
-link command for
+The set of load paths for the user manager instance may be augmented or
+changed using various environment variables. And environment variables may in
+turn be set using environment generators, see
+L<system.environment-generator(7)>.
+In particular, C<\$XDG_DATA_HOME> and
+C<\$XDG_DATA_DIRS> may be easily set using
+L<systemd-environment-d-generator(8)>.
+Thus, directories listed here are just the defaults. To see the actual list that
+would be used based on compilation options and current environment use
+
+
++-+systemd-analyze --user unit-paths
+
+
+
+Moreover, additional units might be loaded into systemd (\"linked\") from
+directories not on the unit load path. See the link command
+for
 L<systemctl(1)>.
-Also, some units are dynamically created via a
-L<systemd.generator(7)>.
 
 This configuration class was generated from systemd documentation.
 by L<parse-man.pl|https://github.com/dod38fr/config-model-systemd/contrib/parse-man.pl>
@@ -255,8 +249,9 @@ effect.',
         },
         'description' => "Configures requirement dependencies on other units. If this unit gets activated, the units
 listed here will be activated as well. If one of the other units fails to activate, and an ordering dependency
-C<After> on the failing unit is set, this
-unit will not be started. This option may be specified more than once or multiple space-separated units may be
+C<After> on the failing unit is set, this unit will not be started. Besides, with or without
+specifying C<After>, this unit will be stopped if one of the other units is explicitly
+stopped. This option may be specified more than once or multiple space-separated units may be
 specified in one option in which case requirement dependencies for all listed names will be created. Note that
 requirement dependencies do not influence the order in which services are started or stopped.  This has to be
 configured independently with the C<After> or C<Before> options. If a unit
@@ -290,7 +285,13 @@ above.",
         'description' => 'Similar to C<Requires>.
 However, if the units listed here are not started already,
 they will not be started and the transaction will fail
-immediately. ',
+immediately.
+
+When C<Requisite=b.service> is used on
+a.service, this dependency will show as
+C<RequisiteOf=a.service> in property listing of
+b.service. C<RequisiteOf>
+dependency cannot be specified directly.',
         'type' => 'list'
       },
       'Wants',
@@ -334,7 +335,13 @@ state for this unit to also be in active state. This not only means a unit bound
 enters inactive state, but also one that is bound to another unit that gets skipped due to a failed condition
 check (such as C<ConditionPathExists>, C<ConditionPathIsSymbolicLink>, \x{2026} \x{2014}
 see below) will be stopped, should it be running. Hence, in many cases it is best to combine
-C<BindsTo> with C<After>.",
+C<BindsTo> with C<After>.
+
+When C<BindsTo=b.service> is used on
+a.service, this dependency will show as
+C<BoundBy=a.service> in property listing of
+b.service. C<BoundBy>
+dependency cannot be specified directly.",
         'type' => 'list'
       },
       'PartOf',
@@ -348,7 +355,13 @@ C<Requires>, but limited to stopping and
 restarting of units. When systemd stops or restarts the units
 listed here, the action is propagated to this unit. Note that
 this is a one-way dependency\x{a0}\x{2014} changes to this unit do not
-affect the listed units. ",
+affect the listed units.
+
+When C<PartOf=b.service> is used on
+a.service, this dependency will show as
+C<ConsistsOf=a.service> in property listing of
+b.service. C<ConsistsOf>
+dependency cannot be specified directly.",
         'type' => 'list'
       },
       'Conflicts',
@@ -441,7 +454,9 @@ invoked and they either failed or reported start-up success.',
       {
         'description' => 'A space-separated list of one or more units
 that are activated when this unit enters the
-C<failed> state.',
+C<failed> state.  A service unit using
+C<Restart> enters the failed state only after
+the start limits are reached.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
@@ -522,6 +537,12 @@ C<--job-mode=> option for details on the
 possible values. If this is set to C<isolate>,
 only a single unit may be listed in
 C<OnFailure>..',
+        'migrate_from' => {
+          'formula' => '$unit',
+          'variables' => {
+            'unit' => '- OnFailureIsolate'
+          }
+        },
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
@@ -636,6 +657,26 @@ ones.',
           'yes'
         ]
       },
+      'CollectMode',
+      {
+        'choice' => [
+          'inactive',
+          'inactive-or-failed'
+        ],
+        'description' => "Tweaks the \"garbage collection\" algorithm for this unit. Takes one of C<inactive>
+or C<inactive-or-failed>. If set to C<inactive> the unit will be unloaded if it is
+in the C<inactive> state and is not referenced by clients, jobs or other units \x{2014} however it
+is not unloaded if it is in the C<failed> state. In C<failed> mode, failed
+units are not unloaded until the user invoked systemctl reset-failed on them to reset the
+C<failed> state, or an equivalent command. This behaviour is altered if this option is set to
+C<inactive-or-failed>: in this case the unit is unloaded even if the unit is in a
+C<failed> state, and thus an explicitly resetting of the C<failed> state is
+not necessary. Note that if this mode is used unit results (such as exit codes, exit signals, consumed
+resources, \x{2026}) are flushed out immediately after the unit completed, except for what is stored in the logging
+subsystem. Defaults to C<inactive>.",
+        'type' => 'leaf',
+        'value_type' => 'enum'
+      },
       'JobTimeoutSec',
       {
         'description' => 'When a job for this unit is queued, a time-out C<JobTimeoutSec> may be
@@ -720,54 +761,6 @@ system call.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
-      'StartLimitIntervalSec',
-      {
-        'description' => 'Configure unit start rate limiting. By default, units which are started more than 5 times
-within 10 seconds are not permitted to start any more times until the 10 second interval ends. With these two
-options, this rate limiting may be modified. Use C<StartLimitIntervalSec> to configure the
-checking interval (defaults to C<DefaultStartLimitIntervalSec> in manager configuration file,
-set to 0 to disable any kind of rate limiting). Use C<StartLimitBurst> to configure how many
-starts per interval are allowed (defaults to C<DefaultStartLimitBurst> in manager
-configuration file). These configuration options are particularly useful in conjunction with the service
-setting C<Restart> (see
-L<systemd.service(5)>); however,
-they apply to all kinds of starts (including manual), not just those triggered by the
-C<Restart> logic. Note that units which are configured for C<Restart> and
-which reach the start limit are not attempted to be restarted anymore; however, they may still be restarted
-manually at a later point, from which point on, the restart logic is again activated. Note that
-systemctl reset-failed will cause the restart rate counter for a service to be flushed,
-which is useful if the administrator wants to manually start a unit and the start limit interferes with
-that. Note that this rate-limiting is enforced after any unit condition checks are executed, and hence unit
-activations with failing conditions are not counted by this rate limiting. Slice, target, device and scope
-units do not enforce this setting, as they are unit types whose activation may either never fail, or may
-succeed only a single time.',
-        'type' => 'leaf',
-        'value_type' => 'uniline'
-      },
-      'StartLimitBurst',
-      {
-        'description' => 'Configure unit start rate limiting. By default, units which are started more than 5 times
-within 10 seconds are not permitted to start any more times until the 10 second interval ends. With these two
-options, this rate limiting may be modified. Use C<StartLimitIntervalSec> to configure the
-checking interval (defaults to C<DefaultStartLimitIntervalSec> in manager configuration file,
-set to 0 to disable any kind of rate limiting). Use C<StartLimitBurst> to configure how many
-starts per interval are allowed (defaults to C<DefaultStartLimitBurst> in manager
-configuration file). These configuration options are particularly useful in conjunction with the service
-setting C<Restart> (see
-L<systemd.service(5)>); however,
-they apply to all kinds of starts (including manual), not just those triggered by the
-C<Restart> logic. Note that units which are configured for C<Restart> and
-which reach the start limit are not attempted to be restarted anymore; however, they may still be restarted
-manually at a later point, from which point on, the restart logic is again activated. Note that
-systemctl reset-failed will cause the restart rate counter for a service to be flushed,
-which is useful if the administrator wants to manually start a unit and the start limit interferes with
-that. Note that this rate-limiting is enforced after any unit condition checks are executed, and hence unit
-activations with failing conditions are not counted by this rate limiting. Slice, target, device and scope
-units do not enforce this setting, as they are unit types whose activation may either never fail, or may
-succeed only a single time.',
-        'type' => 'leaf',
-        'value_type' => 'uniline'
-      },
       'StartLimitAction',
       {
         'choice' => [
@@ -796,15 +789,6 @@ semantics. Defaults to C<none>.',
         'type' => 'leaf',
         'value_type' => 'enum'
       },
-      'RebootArgument',
-      {
-        'description' => 'Configure the optional argument for the
-L<reboot(2)> system call if
-C<StartLimitAction> or a service\'s C<FailureAction> is a reboot action. This
-works just like the optional argument to systemctl reboot command.',
-        'type' => 'leaf',
-        'value_type' => 'uniline'
-      },
       'ConditionArchitecture',
       {
         'cargo' => {
@@ -943,6 +927,8 @@ C<oracle>,
 C<xen>,
 C<bochs>,
 C<uml>,
+C<bhyve>,
+C<qnx>,
 C<openvz>,
 C<lxc>,
 C<lxc-libvirt>,
@@ -1042,6 +1028,44 @@ is, or as left hand side of an assignment. In the latter case,
 the exact assignment is looked for with right and left hand
 side matching.
 
+If multiple conditions are specified, the unit will be
+executed if all of them apply (i.e. a logical AND is applied).
+Condition checks can be prefixed with a pipe symbol (|) in
+which case a condition becomes a triggering condition. If at
+least one triggering condition is defined for a unit, then the
+unit will be executed if at least one of the triggering
+conditions apply and all of the non-triggering conditions. If
+you prefix an argument with the pipe symbol and an exclamation
+mark, the pipe symbol must be passed first, the exclamation
+second. Except for
+C<ConditionPathIsSymbolicLink=>, all path
+checks follow symlinks. If any of these options is assigned
+the empty string, the list of conditions is reset completely,
+all previous condition settings (of any kind) will have no
+effect.",
+        'type' => 'list'
+      },
+      'ConditionKernelVersion',
+      {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
+starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
+respected. A failing condition will not result in the unit being moved into a failure state. The condition is
+checked at the time the queued start job is to be executed. Use condition expressions in order to silently skip
+units that do not apply to the local running system, for example because the kernel or runtime environment
+doesn't require its functionality. Use the various C<AssertArchitecture=>,
+C<AssertVirtualization=>, \x{2026} options for a similar mechanism that puts the unit in a failure
+state and logs about the failed check (see below).
+
+C<ConditionKernelVersion=> may be used to check whether the kernel version (as reported
+by uname -r) matches a certain expression (or if prefixed with the exclamation mark does not
+match it). The argument must be a single string. If the string starts with one of C<<>,
+C<<=>, C<=>, C<>=>, C<>> a relative
+version comparison is done, otherwise the specified string is matched with shell-style globs.
+
 If multiple conditions are specified, the unit will be
 executed if all of them apply (i.e. a logical AND is applied).
 Condition checks can be prefixed with a pipe symbol (|) in
@@ -1079,6 +1103,7 @@ check whether the given security module is enabled on the
 system. Currently, the recognized values are
 C<selinux>,
 C<apparmor>,
+C<tomoyo>,
 C<ima>,
 C<smack> and
 C<audit>. The test may be negated by
@@ -1670,6 +1695,50 @@ service manager's real or effective group, or any of its
 auxiliary groups match the specified group or GID. This setting
 does not have a special value C<\@system>.
 
+If multiple conditions are specified, the unit will be
+executed if all of them apply (i.e. a logical AND is applied).
+Condition checks can be prefixed with a pipe symbol (|) in
+which case a condition becomes a triggering condition. If at
+least one triggering condition is defined for a unit, then the
+unit will be executed if at least one of the triggering
+conditions apply and all of the non-triggering conditions. If
+you prefix an argument with the pipe symbol and an exclamation
+mark, the pipe symbol must be passed first, the exclamation
+second. Except for
+C<ConditionPathIsSymbolicLink=>, all path
+checks follow symlinks. If any of these options is assigned
+the empty string, the list of conditions is reset completely,
+all previous condition settings (of any kind) will have no
+effect.",
+        'type' => 'list'
+      },
+      'ConditionControlGroupController',
+      {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
+starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
+respected. A failing condition will not result in the unit being moved into a failure state. The condition is
+checked at the time the queued start job is to be executed. Use condition expressions in order to silently skip
+units that do not apply to the local running system, for example because the kernel or runtime environment
+doesn't require its functionality. Use the various C<AssertArchitecture=>,
+C<AssertVirtualization=>, \x{2026} options for a similar mechanism that puts the unit in a failure
+state and logs about the failed check (see below).
+
+C<ConditionControlGroupController=> takes a
+cgroup controller name (eg. C<cpu>), verifying that it is
+available for use on the system. For example, a particular controller
+may not be available if it was disabled on the kernel command line with
+C<cgroup_disable=>controller.
+Multiple controllers may be passed with a space separating them; in
+this case the condition will only pass if all listed controllers are
+available for use. Controllers unknown to systemd are ignored. Valid
+controllers are C<cpu>, C<cpuacct>,
+C<io>, C<blkio>, C<memory>,
+C<devices>, and C<pids>.
+
 If multiple conditions are specified, the unit will be
 executed if all of them apply (i.e. a logical AND is applied).
 Condition checks can be prefixed with a pipe symbol (|) in
@@ -1727,6 +1796,17 @@ C<ConditionVirtualization>, \x{2026}, condition settings described above, these
 assertion checks to the start-up of the unit. However, unlike the conditions settings, any assertion setting
 that is not met results in failure of the start job (which means this is logged loudly). Use assertion
 expressions for units that cannot operate when specific requirements are not met, and when this is something
+the administrator or user should look into.",
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'AssertKernelVersion',
+      {
+        'description' => "Similar to the C<ConditionArchitecture>,
+C<ConditionVirtualization>, \x{2026}, condition settings described above, these settings add
+assertion checks to the start-up of the unit. However, unlike the conditions settings, any assertion setting
+that is not met results in failure of the start job (which means this is logged loudly). Use assertion
+expressions for units that cannot operate when specific requirements are not met, and when this is something
 the administrator or user should look into.",
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -1903,6 +1983,17 @@ C<ConditionVirtualization>, \x{2026}, condition settings described above, these
 assertion checks to the start-up of the unit. However, unlike the conditions settings, any assertion setting
 that is not met results in failure of the start job (which means this is logged loudly). Use assertion
 expressions for units that cannot operate when specific requirements are not met, and when this is something
+the administrator or user should look into.",
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'AssertControlGroupController',
+      {
+        'description' => "Similar to the C<ConditionArchitecture>,
+C<ConditionVirtualization>, \x{2026}, condition settings described above, these settings add
+assertion checks to the start-up of the unit. However, unlike the conditions settings, any assertion setting
+that is not met results in failure of the start job (which means this is logged loudly). Use assertion
+expressions for units that cannot operate when specific requirements are not met, and when this is something
 the administrator or user should look into.",
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -1917,6 +2008,20 @@ files. This functionality should not be used in normal
 units.',
         'type' => 'leaf',
         'value_type' => 'uniline'
+      },
+      'StartLimitInterval',
+      {
+        'status' => 'deprecated',
+        'type' => 'leaf',
+        'value_type' => 'uniline',
+        'warn' => 'StartLimitInterval is now StartLimitIntervalSec. Migrating...'
+      },
+      'OnFailureIsolate',
+      {
+        'status' => 'deprecated',
+        'type' => 'leaf',
+        'value_type' => 'uniline',
+        'warn' => 'OnFailureIsolate is now OnFailureJobMode. Migrating...'
       }
     ],
     'generated_by' => 'parse-man.pl from systemd doc',
